@@ -31,13 +31,14 @@
 #               'id' => 'serv16'
 #            }
 #      ],
-#   
+#
 package EBox::Services::Model::ServiceConfigurationTable;
 
 use EBox::Global;
 use EBox::Gettext;
 use EBox::Validate qw(:all);
 use EBox::Exceptions::External;
+use EBox::View::Customizer;
 
 use EBox::Types::Select;
 use EBox::Types::PortRange;
@@ -50,7 +51,7 @@ use warnings;
 
 use base 'EBox::Model::DataTable';
 
-sub new 
+sub new
 {
         my $class = shift;
         my %parms = @_;
@@ -61,7 +62,7 @@ sub new
         return $self;
 }
 
-sub protocols 
+sub protocols
 {
         my ($self) = @_;
 
@@ -102,10 +103,37 @@ sub protocols
 
 }
 
+# Method: viewCustomizer
+#
+#   Overrides <EBox::Model::DataTable::viewCustomizer> to implement
+#   a custom behaviour to show and hide source and destination ports
+#   depending on the protocol
+#
+#
+sub viewCustomizer
+{
+    my ($self) = @_;
+    my $customizer = new EBox::View::Customizer();
+    $customizer->setModel($self);
+    $customizer->setOnChangeActions(
+            { protocol =>
+                {
+                any => { disable => [qw/source destination/] },
+                icmp => { disable => [qw/source destination/] },
+                gre => { disable => [qw/source destination/] },
+                esp => { disable => [qw/source destination/] },
+                tcp => { enable => [qw/source destination/] },
+                udp => { enable => [qw/source destination/] },
+                'tcp/udp' => { enable => [qw/source destination/] },
+                }
+                });
+    return $customizer;
+}
+
 sub _table
 {
-        my @tableHead = 
-                ( 
+        my @tableHead =
+                (
                  new EBox::Types::Select(
                          'fieldName' => 'protocol',
                          'printableName' => __('Protocol'),
@@ -127,8 +155,8 @@ sub _table
 
 
 
-        my $dataTable = 
-        { 
+        my $dataTable =
+        {
                 'tableName' => 'ServiceConfigurationTable',
                 'printableTableName' => __('Service configuration'),
                 'defaultController' =>
@@ -139,6 +167,7 @@ sub _table
                 'menuNamespace' => 'Services/View/ServiceConfigurationTable',
                 'class' => 'dataTable',
                 'help' => '', # FIXME
+                'rowUnique' => 1,
                 'printableRowName' => __('service'),
         };
 
