@@ -15,10 +15,10 @@
 
 # Class: EBox::Services
 #
-# 	This class is used to abstract services composed of
-# 	protocols and ports.
+#       This class is used to abstract services composed of
+#       protocols and ports.
+#
 #
-# 	
 
 package EBox::Services;
 
@@ -47,11 +47,11 @@ sub _create
             title => __n('Services'),
             domain => 'ebox-services',
             @_);
-    $self->{'serviceModel'} = 
+    $self->{'serviceModel'} =
         new EBox::Services::Model::ServiceTable(
                 'gconfmodule' => $self,
                 'directory' => 'serviceTable');
-    $self->{'serviceConfigurationModel'} = 
+    $self->{'serviceConfigurationModel'} =
         new EBox::Services::Model::ServiceConfigurationTable(
                 'gconfmodule' => $self,
                 'directory' => 'serviceConfigurationTable');
@@ -110,16 +110,16 @@ sub _exposedMethods
 
 # Method: serviceNames
 #
-# 	Fetch all the service identifiers and names
+#       Fetch all the service identifiers and names
 #
 # Returns:
 #
-# 	Array ref of  hash refs which contain:
+#       Array ref of  hash refs which contain:
 #
-# 	'id' - service identifier
-# 	'name' service name
+#       'id' - service identifier
+#       'name' service name
 #
-#	Example:
+#       Example:
 #         [
 #          {
 #            'name' => 'ssh',
@@ -134,10 +134,15 @@ sub serviceNames
 {
     my ($self) = @_;
 
+    my $servicesModel = $self->{'serviceModel'};
     my @services;
-    foreach my $service (@{$self->{'serviceModel'}->printableValueRows()}) {
-        push (@services, {'id' => $service->{'id'}, 
-                'name' => $service->{'name'}});
+
+    foreach my $id (@{$servicesModel->ids()}) {
+        my $name = $servicesModel->row($id)->valueByName('name');
+        push @services, {
+            'id' => $id,
+            'name' => $name
+           };
     }
 
     return \@services;
@@ -145,24 +150,24 @@ sub serviceNames
 
 # Method: serviceConfiguration
 #
-#	For a given service identifier it returns its service configuration,
-#	that is, the set of protocols and ports.
+#       For a given service identifier it returns its service configuration,
+#       that is, the set of protocols and ports.
 #
 # Returns:
 #
-# 	Array ref of  hash refs which contain:
-#	
-#	protocol - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
-#	source	 - it can take: 
-#   			"any"
-#	    		An integer from 1 to 65536 -> 22
-#		    	Two integers separated by colons -> 22:25 
-#	destination - same as source
+#       Array ref of  hash refs which contain:
 #
-#	Example:
+#       protocol - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
+#       source   - it can take:
+#                       "any"
+#                       An integer from 1 to 65536 -> 22
+#                       Two integers separated by colons -> 22:25
+#       destination - same as source
 #
-#	     'protocol' => 'tcp',
-#	     'source' => 'any',
+#       Example:
+#
+#            'protocol' => 'tcp',
+#            'source' => 'any',
 #       'destination' => '21:22',
 sub serviceConfiguration
 {
@@ -180,8 +185,9 @@ sub serviceConfiguration
     my $model = $row->subModel('configuration');
 
     my @conf;
-    for my $subRow (@{$model->rows()}) {
-        push (@conf, { 
+    for my $id (@{$model->ids()}) {
+	my $subRow = $model->row($id);
+        push (@conf, {
                         'protocol' => $subRow->valueByName('protocol'),
                         'source' => $subRow->valueByName('source'),
                         'destination' => $subRow->valueByName('destination')
@@ -191,52 +197,52 @@ sub serviceConfiguration
     return \@conf;
 }
 
-# Method: addService 
+# Method: addService
 #
-#   Add a service to the services table	
+#   Add a service to the services table
 #
 # Parameters:
 #
 #   (NAMED)
-#   
+#
 #   name        - service's name
 #   description - service's description
-#	protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
-#	sourcePort  - it can take: 
+#       protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
+#       sourcePort  - it can take:
 #                   "any"
 #                    An integer from 1 to 65536 -> 22
-#                   Two integers separated by colons -> 22:25 
-#	destinationPort - same as source
+#                   Two integers separated by colons -> 22:25
+#       destinationPort - same as source
 #   internal - boolean, internal services can't be modified from the UI
 #   readOnly - boolean, set the row unremovable from the UI
 #   translationDomain - eBox module domain for i18n
 #
-#	Example:
+#       Example:
 #
 #       'name' => 'ssh',
 #       'description' => 'secure shell'.
-#	    'protocol' => 'tcp',
-#	    'sourcePort' => 'any',
+#           'protocol' => 'tcp',
+#           'sourcePort' => 'any',
 #       'destinationPort' => '21:22',
 #
 #   Returns:
 #
-#   string - id of the new created row  
-sub addService 
+#   string - id of the new created row
+sub addService
 {
     my ($self, %params) = @_;
 
     return $self->{'serviceModel'}->addService(%params);
 }
 
-# Method: addMultipleService 
+# Method: addMultipleService
 #
-#   Add a multi protocol service to the services table	
+#   Add a multi protocol service to the services table
 #
 # Parameters:
 #
 #   (NAMED)
-#   
+#
 #   name        - service's name
 #   description - service's description
 #   internal - boolean, internal services can't be modified from the UI
@@ -244,68 +250,68 @@ sub addService
 #
 #   services - array ref of hash ref containing:
 #
-#	    protocol    - it can take one of these: any, tcp, udp, 
-#	                                            tcp/udp, grep, icmp
-#	    sourcePort  - it can take:  "any"
+#           protocol    - it can take one of these: any, tcp, udp,
+#                                                   tcp/udp, grep, icmp
+#           sourcePort  - it can take:  "any"
 #                                   An integer from 1 to 65536 -> 22
-#                                   Two integers separated by colons -> 22:25 
-#	    destinationPort - same as source
+#                                   Two integers separated by colons -> 22:25
+#           destinationPort - same as source
 #
 #
-#	Example:
+#       Example:
 #
 #       'name' => 'ssh',
 #       'description' => 'secure shell'.
-#       'services' => [ 
+#       'services' => [
 #                       {
-#	                        'protocol' => 'tcp',
-#	                        'sourcePort' => 'any',
+#                               'protocol' => 'tcp',
+#                               'sourcePort' => 'any',
 #                           'destinationPort' => '21:22'
 #                        },
 #                        {
-#	                        'protocol' => 'tcp',
-#	                        'sourcePort' => 'any',
+#                               'protocol' => 'tcp',
+#                               'sourcePort' => 'any',
 #                           'destinationPort' => '21:22'
 #                        }
 #                     ];
 #
 #   Returns:
 #
-#   string - id of the new created row  
-sub addMultipleService 
+#   string - id of the new created row
+sub addMultipleService
 {
     my ($self, %params) = @_;
 
     return $self->{'serviceModel'}->addMultipleService(%params);
 }
 
-# Method: setService 
+# Method: setService
 #
-#   Set a existing service to the services table	
+#   Set a existing service to the services table
 #
 # Parameters:
 #
 #   (NAMED)
-#   
+#
 #   name        - service's name
 #   description - service's description
-#	protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
-#	sourcePort  - it can take: 
+#       protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
+#       sourcePort  - it can take:
 #                   "any"
 #                    An integer from 1 to 65536 -> 22
-#                   Two integers separated by colons -> 22:25 
-#	destinationPort - same as source
+#                   Two integers separated by colons -> 22:25
+#       destinationPort - same as source
 #   internal - boolean, internal services can't be modified from the UI
 #   readOnly - boolean, set the row unremovable from the UI
 #
-#	Example:
+#       Example:
 #
 #       'name' => 'ssh',
 #       'description' => 'secure shell'.
-#	    'protocol' => 'tcp',
-#	    'sourcePort' => 'any',
+#           'protocol' => 'tcp',
+#           'sourcePort' => 'any',
 #       'destinationPort' => '21:22',
-sub setService 
+sub setService
 {
     my ($self, %params) = @_;
 
@@ -314,19 +320,19 @@ sub setService
 
 # Method: setAdministrationPort
 #
-#	Set administration port on service
+#       Set administration port on service
 #
 # Parameters:
 #
-#	port - port
-#	
+#       port - port
+#
 sub setAdministrationPort
 {
     my ($self, $port) = @_;
 
     checkPort($port, __("port"));
 
-	$self->setService('name' => __d('eBox administration'),
+        $self->setService('name' => __d('eBox administration'),
                 'description' => __d('eBox Administration port'),
                 'domain' => __d('ebox-services'),
                 'protocol' => 'tcp',
@@ -337,16 +343,16 @@ sub setAdministrationPort
 
 }
 
-# Method: availablePort 
+# Method: availablePort
 #
-#	Check if a given port for a given protocol is available. That is,
-#	no internal service uses it.
+#       Check if a given port for a given protocol is available. That is,
+#       no internal service uses it.
 #
 # Parameters:
 #
 #   (POSITIONAL)
 #   protocol   - it can take one of these: tcp, udp
-#   port 	   - An integer from 1 to 65536 -> 22
+#   port           - An integer from 1 to 65536 -> 22
 #
 # Returns:
 #   boolean - true if it's available, otherwise false
@@ -358,19 +364,19 @@ sub availablePort
     return $self->{'serviceModel'}->availablePort(%params);
 }
 
-# Method: removeService 
+# Method: removeService
 #
-#  Remove a service from the  services table	
+#  Remove a service from the  services table
 #
 # Parameters:
-# 
+#
 #   (NAMED)
-#   
+#
 #   You can select the service using one of the following parameters:
-#       
+#
 #       name - service's name
 #       id - service's id
-sub removeService 
+sub removeService
 {
     my ($self, %params) = @_;
 
@@ -401,7 +407,7 @@ sub removeService
 #
 #   (NAMED)
 #   You can select the service using one of the following parameters:
-#       
+#
 #       name - service's name
 #       id - service's id
 sub serviceExists
@@ -411,7 +417,7 @@ sub serviceExists
     unless (exists $params{'id'} or exists $params{'name'}) {
         throw EBox::Exceptions::MissingArgument('service');
     }
-    
+
     my $model =  $self->{'serviceModel'};
     my $id = $params{'id'};
 
@@ -424,7 +430,7 @@ sub serviceExists
     }
 
     return defined($row);
-}    
+}
 
 # Method: serviceId
 #
@@ -446,17 +452,17 @@ sub serviceId
     unless (defined($name)) {
         throw EBox::Exceptions::MissingArgument('name');
     }
-    
+
     my $model =  $self->{'serviceModel'};
     my $row = $model->findValue('name' => $name);
-    
+
     return $row->id();
 }
 
-# Method: menu 
+# Method: menu
 #
 #       Overrides EBox::Module method.
-#   
+#
 #
 sub menu
 {
@@ -464,7 +470,8 @@ sub menu
     my $item = new EBox::Menu::Item(
     'url' => 'Services/View/ServiceTable',
     'text' => __($self->title),
-    'order' => 3);
+    'separator' => __('Core'),
+    'order' => 60);
     $root->add($item);
 }
 
